==> ejc-accplat-impl-3.0.0-20231229.082139-55-sources.jar: com/ejianc/business/accplat/config/bean/BillAccbookSetEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 会计平台设置-账簿映射规则
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_accbook_set")
public class BillAccbookSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="source_org_id")
    private Long sourceOrgId; // 来源组织id
    @TableField(value="source_org_name")
    private String sourceOrgName; // 来源组织名称
    @TableField(value="condition_view")
    private String conditionView; // 条件显示
    @TableField(value="condition_expression")
    private String conditionExpression; // 条件逻辑表达式
    @TableField(value="accbook_id")
    private Long accbookId; // 目标账簿ID
    @TableField(value="accbook_code")
    private String accbookCode; // 目标账簿编码
    @TableField(value="accbook_name")
    private String accbookName; // 目标账簿名称
    
    
    

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getSourceOrgId() {
        return sourceOrgId;
    }

    public void setSourceOrgId(Long sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    public String getSourceOrgName() {
        return sourceOrgName;
    }

    public void setSourceOrgName(String sourceOrgName) {
        this.sourceOrgName = sourceOrgName;
    }
    public String getConditionView() {
        return conditionView;
    }

    public void setConditionView(String conditionView) {
        this.conditionView = conditionView;
    }
    public String getConditionExpression() {
        return conditionExpression;
    }

    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }
    public Long getAccbookId() {
        return accbookId;
    }

    public void setAccbookId(Long accbookId) {
        this.accbookId = accbookId;
    }
    public String getAccbookCode() {
        return accbookCode;
    }

    public void setAccbookCode(String accbookCode) {
        this.accbookCode = accbookCode;
    }
    public String getAccbookName() {
        return accbookName;
    }

    public void setAccbookName(String accbookName) {
        this.accbookName = accbookName;
    }
    
}

==> ejc-accplat-impl-3.0.0-20240513.060048-183-sources.jar: com/ejianc/business/accplat/config/bean/BillAccbookSetEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 会计平台设置-账簿映射规则
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_accbook_set")
public class BillAccbookSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="source_org_id")
    private Long sourceOrgId; // 来源组织id
    @TableField(value="source_org_name")
    private String sourceOrgName; // 来源组织名称
    @TableField(value="condition_view")
    private String conditionView; // 条件显示
    @TableField(value="condition_expression")
    private String conditionExpression; // 条件逻辑表达式
    @TableField(value="accbook_id")
    private Long accbookId; // 目标账簿ID
    @TableField(value="accbook_code")
    private String accbookCode; // 目标账簿编码
    @TableField(value="accbook_name")
    private String accbookName; // 目标账簿名称

    @TableField(value="subject_chart_id")
    private Long subjectChartId; // 科目表
    @TableField(value="subject_chart_name")
    private String subjectChartName; // 科目表
    
    
    

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getSourceOrgId() {
        return sourceOrgId;
    }

    public void setSourceOrgId(Long sourceOrgId) {
        this.sourceOrgId = sourceOrgId;
    }
    public String getSourceOrgName() {
        return sourceOrgName;
    }

    public void setSourceOrgName(String sourceOrgName) {
        this.sourceOrgName = sourceOrgName;
    }
    public String getConditionView() {
        return conditionView;
    }

    public void setConditionView(String conditionView) {
        this.conditionView = conditionView;
    }
    public String getConditionExpression() {
        return conditionExpression;
    }

    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }
    public Long getAccbookId() {
        return accbookId;
    }

    public void setAccbookId(Long accbookId) {
        this.accbookId = accbookId;
    }
    public String getAccbookCode() {
        return accbookCode;
    }

    public void setAccbookCode(String accbookCode) {
        this.accbookCode = accbookCode;
    }
    public String getAccbookName() {
        return accbookName;
    }

    public void setAccbookName(String accbookName) {
        this.accbookName = accbookName;
    }


    public Long getSubjectChartId() {
        return subjectChartId;
    }

    public void setSubjectChartId(Long subjectChartId) {
        this.subjectChartId = subjectChartId;
    }

    public String getSubjectChartName() {
        return subjectChartName;
    }

    public void setSubjectChartName(String subjectChartName) {
        this.subjectChartName = subjectChartName;
    }
}
